pub enum Error<E> {
ServerDisappeared,
OriginDisappeared,
ClientsDisappeared,
NoReply,
App(E),
}Expand description
Module-specific error codes.
Variants
ServerDisappeared
The server object has shut down.
This happens when clients:
- attempt to send messages to a server that has been deallocated.
- have their requests dropped from the serrver’s queue because the server itself was deallocated.
OriginDisappeared
A message reply could not be completed because the original requestor disappearing.
ClientsDisappeared
All the client objects have shut down.
This happens when a server attempts to pull the latest node on off the queue, but there are no more nodes on the queue and all the associated client objects have been released (impled: New nodes can never be added to the queue).
NoReply
The message was delivered to the server, but the reply context was released before sending back a reply.
App(E)
Application-specific error.
The E type is typically declared as the third generic parameter to
channel.
Implementations
Sourceimpl<E> Error<E>
impl<E> Error<E>
Sourcepub fn into_apperr(self) -> Option<E>
pub fn into_apperr(self) -> Option<E>
Get application-specific error.
Will return None is the error is not Error::App.
Sourcepub fn unwrap_apperr(self) -> E
pub fn unwrap_apperr(self) -> E